@@ -38,7 +38,7 @@ from snaptrade_client.rest import AsyncResponseWrapper, ResponseWrapper
 from snaptrade_client.configuration import Configuration
 from snaptrade_client.exceptions import ApiTypeError, ApiValueError, MissingRequiredParametersError
 from snaptrade_client.request_after_hook import request_after_hook
-from snaptrade_client.request_before_hook import request_before_hook
+from snaptrade_client.request_before_url_hook import request_before_url_hook
 from snaptrade_client.schemas import (
     NoneClass,
     BoolClass,
@@ -1137,7 +1137,7 @@ class ApiClient:
             self.default_headers[header_name] = header_value
         self.cookie = cookie
         # Set default User-Agent.
-        self.user_agent = 'Konfig/10.18.0/python'
+        self.user_agent = 'Konfig/10.28.0/python'
 
     def __enter__(self):
         return self
@@ -1190,44 +1190,44 @@ class ApiClient:
         prefix_separator_iterator: PrefixSeparatorIterator = None,
     ) -> AsyncResponseWrapper:
 
-        request_before_hook(
-            resource_path=resource_path,
-            method=method,
-            configuration=self.configuration,
-            body=body,
-            fields=fields,
-            auth_settings=auth_settings,
-            headers=headers,
-        )
-
         # header parameters
         used_headers = HTTPHeaderDict(self.default_headers)
         if self.cookie:
             headers['Cookie'] = self.cookie
 
         # auth setting
-        resource_path = self.update_params_for_auth(
+        resource_path_ref = [self.update_params_for_auth(
             used_headers,
             auth_settings,
             resource_path,
             method,
             body,
             prefix_separator_iterator
-        )
+        )]
 
         # must happen after cookie setting and auth setting in case user is overriding those
         if headers:
             used_headers.update(headers)
 
+        request_before_url_hook(
+            resource_path_ref=resource_path_ref,
+            method=method,
+            configuration=self.configuration,
+            body=body,
+            fields=fields,
+            auth_settings=auth_settings,
+            headers=used_headers,
+        )
+
         # request url
         if host is None:
-            url = self.configuration.host + resource_path
+            url = self.configuration.host + resource_path_ref[0]
         else:
             # use server/host defined in path or operation instead
-            url = host + resource_path
+            url = host + resource_path_ref[0]
 
         request_after_hook(
-            resource_path=resource_path,
+            resource_path=resource_path_ref[0],
             method=method,
             configuration=self.configuration,
             body=body,
@@ -1265,44 +1265,44 @@ class ApiClient:
         prefix_separator_iterator: PrefixSeparatorIterator = None,
     ) -> ResponseWrapper:
 
-        request_before_hook(
-            resource_path=resource_path,
-            method=method,
-            configuration=self.configuration,
-            body=body,
-            fields=fields,
-            auth_settings=auth_settings,
-            headers=headers,
-        )
-
         # header parameters
         used_headers = HTTPHeaderDict(self.default_headers)
         if self.cookie:
             headers['Cookie'] = self.cookie
 
         # auth setting
-        resource_path = self.update_params_for_auth(
+        resource_path_ref = [self.update_params_for_auth(
             used_headers,
             auth_settings,
             resource_path,
             method,
             body,
             prefix_separator_iterator
-        )
+        )]
 
         # must happen after cookie setting and auth setting in case user is overriding those
         if headers:
             used_headers.update(headers)
 
+        request_before_url_hook(
+            resource_path_ref=resource_path_ref,
+            method=method,
+            configuration=self.configuration,
+            body=body,
+            fields=fields,
+            auth_settings=auth_settings,
+            headers=used_headers,
+        )
+
         # request url
         if host is None:
-            url = self.configuration.host + resource_path
+            url = self.configuration.host + resource_path_ref[0]
         else:
             # use server/host defined in path or operation instead
-            url = host + resource_path
+            url = host + resource_path_ref[0]
 
         request_after_hook(
-            resource_path=resource_path,
+            resource_path=resource_path_ref[0],
             method=method,
             configuration=self.configuration,
             body=body,
