@@ -15,6 +15,7 @@ from snaptrade_client.model.account import Account
 from snaptrade_client.model.account_holdings import AccountHoldings
 from snaptrade_client.model.account_holdings_account import AccountHoldingsAccount
 from snaptrade_client.model.account_ids import AccountIDs
+from snaptrade_client.model.account_meta import AccountMeta
 from snaptrade_client.model.account_order_record import AccountOrderRecord
 from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus
 from snaptrade_client.model.account_simple import AccountSimple
@@ -24,11 +25,15 @@ from snaptrade_client.model.balance import Balance
 from snaptrade_client.model.brokerage import Brokerage
 from snaptrade_client.model.brokerage_auth_ids import BrokerageAuthIDs
 from snaptrade_client.model.brokerage_authorization import BrokerageAuthorization
+from snaptrade_client.model.brokerage_authorization_meta import BrokerageAuthorizationMeta
 from snaptrade_client.model.brokerage_authorization_type import BrokerageAuthorizationType
 from snaptrade_client.model.brokerage_authorization_type_read_only import BrokerageAuthorizationTypeReadOnly
+from snaptrade_client.model.brokerage_authorization_type_read_only_brokerage import BrokerageAuthorizationTypeReadOnlyBrokerage
+from snaptrade_client.model.brokerage_exchanges import BrokerageExchanges
 from snaptrade_client.model.brokerage_symbol import BrokerageSymbol
 from snaptrade_client.model.brokerage_type import BrokerageType
 from snaptrade_client.model.calculated_trade import CalculatedTrade
+from snaptrade_client.model.cancelled_units import CancelledUnits
 from snaptrade_client.model.cash import Cash
 from snaptrade_client.model.cash_restriction import CashRestriction
 from snaptrade_client.model.client_id import ClientID
@@ -38,9 +43,11 @@ from snaptrade_client.model.delete_user_response import DeleteUserResponse
 from snaptrade_client.model.dividend_at_date import DividendAtDate
 from snaptrade_client.model.email import Email
 from snaptrade_client.model.encrypted_response import EncryptedResponse
+from snaptrade_client.model.encrypted_response_encrypted_message_data import EncryptedResponseEncryptedMessageData
 from snaptrade_client.model.exchange import Exchange
 from snaptrade_client.model.exchange_rate_pairs import ExchangeRatePairs
 from snaptrade_client.model.excluded_asset import ExcludedAsset
+from snaptrade_client.model.filled_units import FilledUnits
 from snaptrade_client.model.id import Id
 from snaptrade_client.model.jwt import JWT
 from snaptrade_client.model.login_redirect_uri import LoginRedirectURI
@@ -63,9 +70,16 @@ from snaptrade_client.model.model_portfolio_security import ModelPortfolioSecuri
 from snaptrade_client.model.monthly_dividends import MonthlyDividends
 from snaptrade_client.model.net_contributions import NetContributions
 from snaptrade_client.model.net_dividend import NetDividend
+from snaptrade_client.model.open_units import OpenUnits
 from snaptrade_client.model.option_chain import OptionChain
+from snaptrade_client.model.option_chain_item import OptionChainItem
+from snaptrade_client.model.option_chain_item_chain_per_root import OptionChainItemChainPerRoot
+from snaptrade_client.model.option_chain_item_chain_per_root_item import OptionChainItemChainPerRootItem
+from snaptrade_client.model.option_chain_item_chain_per_root_item_chain_per_strike_price import OptionChainItemChainPerRootItemChainPerStrikePrice
+from snaptrade_client.model.option_chain_item_chain_per_root_item_chain_per_strike_price_item import OptionChainItemChainPerRootItemChainPerStrikePriceItem
 from snaptrade_client.model.option_leg import OptionLeg
 from snaptrade_client.model.option_strategy import OptionStrategy
+from snaptrade_client.model.option_strategy_legs import OptionStrategyLegs
 from snaptrade_client.model.options_holdings import OptionsHoldings
 from snaptrade_client.model.options_position import OptionsPosition
 from snaptrade_client.model.options_symbol import OptionsSymbol
@@ -74,6 +88,7 @@ from snaptrade_client.model.partner_data import PartnerData
 from snaptrade_client.model.past_value import PastValue
 from snaptrade_client.model.percent import Percent
 from snaptrade_client.model.performance_custom import PerformanceCustom
+from snaptrade_client.model.performance_custom_bad_tickers import PerformanceCustomBadTickers
 from snaptrade_client.model.portfolio_group import PortfolioGroup
 from snaptrade_client.model.portfolio_group_info import PortfolioGroupInfo
 from snaptrade_client.model.portfolio_group_position import PortfolioGroupPosition
@@ -92,6 +107,8 @@ from snaptrade_client.model.signed_content import SignedContent
 from snaptrade_client.model.snap_trade_api_disclaimer_accept_status import SnapTradeAPIDisclaimerAcceptStatus
 from snaptrade_client.model.snap_trade_holdings_account import SnapTradeHoldingsAccount
 from snaptrade_client.model.snap_trade_holdings_account_account_id import SnapTradeHoldingsAccountAccountId
+from snaptrade_client.model.snap_trade_holdings_account_account_id_meta import SnapTradeHoldingsAccountAccountIdMeta
+from snaptrade_client.model.snap_trade_holdings_account_meta import SnapTradeHoldingsAccountMeta
 from snaptrade_client.model.snap_trade_holdings_total_value import SnapTradeHoldingsTotalValue
 from snaptrade_client.model.snap_trade_login_user_request_body import SnapTradeLoginUserRequestBody
 from snaptrade_client.model.snap_trade_register_user_request_body import SnapTradeRegisterUserRequestBody
@@ -100,10 +117,17 @@ from snaptrade_client.model.snap_trade_user_secret import SnapTradeUserSecret
 from snaptrade_client.model.status import Status
 from snaptrade_client.model.stop_price import StopPrice
 from snaptrade_client.model.strategy_impact import StrategyImpact
+from snaptrade_client.model.strategy_impact_legs import StrategyImpactLegs
+from snaptrade_client.model.strategy_impact_legs_item import StrategyImpactLegsItem
 from snaptrade_client.model.strategy_order_place import StrategyOrderPlace
+from snaptrade_client.model.strategy_order_place_orders import StrategyOrderPlaceOrders
+from snaptrade_client.model.strategy_order_place_orders_item import StrategyOrderPlaceOrdersItem
+from snaptrade_client.model.strategy_order_place_orders_item_legs import StrategyOrderPlaceOrdersItemLegs
+from snaptrade_client.model.strategy_order_place_orders_item_legs_item import StrategyOrderPlaceOrdersItemLegsItem
 from snaptrade_client.model.strategy_order_quotes import StrategyOrderQuotes
 from snaptrade_client.model.strategy_order_record import StrategyOrderRecord
 from snaptrade_client.model.strategy_quotes import StrategyQuotes
+from snaptrade_client.model.strategy_quotes_greek import StrategyQuotesGreek
 from snaptrade_client.model.sub_period_return_rate import SubPeriodReturnRate
 from snaptrade_client.model.symbol import Symbol
 from snaptrade_client.model.symbol_query import SymbolQuery
@@ -111,11 +135,13 @@ from snaptrade_client.model.symbols_quotes import SymbolsQuotes
 from snaptrade_client.model.sync_status_date import SyncStatusDate
 from snaptrade_client.model.target_asset import TargetAsset
 from snaptrade_client.model.target_asset_list import TargetAssetList
+from snaptrade_client.model.target_asset_meta import TargetAssetMeta
 from snaptrade_client.model.time import Time
 from snaptrade_client.model.time_in_force import TimeInForce
 from snaptrade_client.model.timestamp import Timestamp
 from snaptrade_client.model.trade import Trade
 from snaptrade_client.model.trade_execution_status import TradeExecutionStatus
+from snaptrade_client.model.trade_execution_status_meta import TradeExecutionStatusMeta
 from snaptrade_client.model.trade_impact import TradeImpact
 from snaptrade_client.model.transactions_status import TransactionsStatus
 from snaptrade_client.model.us_exchange import USExchange
