@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -39,6 +40,7 @@ from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchem
 from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
 from snaptrade_client.model.manual_trade_form import ManualTradeForm as ManualTradeFormSchema
 from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse as Model403FailedRequestResponseSchema
+from snaptrade_client.model.price import Price as PriceSchema
 
 from snaptrade_client.type.action import Action
 from snaptrade_client.type.time_in_force import TimeInForce
@@ -47,6 +49,7 @@ from snaptrade_client.type.manual_trade_and_impact import ManualTradeAndImpact
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
 from snaptrade_client.type.stop_price import StopPrice
 from snaptrade_client.type.model403_failed_request_response import Model403FailedRequestResponse
+from snaptrade_client.type.price import Price
 from snaptrade_client.type.order_type import OrderType
 
 from . import path
@@ -203,7 +206,7 @@ class BaseApi(api_client.Api):
         account_id: typing.Optional[str] = None,
         action: typing.Optional[Action] = None,
         order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -279,21 +282,31 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         if body is schemas.unset:
             raise exceptions.ApiValueError(
                 'The required body parameter has an invalid value of: unset. Set a valid value instead')
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         serialized_data = request_body_manual_trade_form.serialize(body, content_type)
-        _headers.add('Content-Type', content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
-            _body = serialized_data['body']    
+            _body = serialized_data['body']
+    
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -302,8 +315,16 @@ class BaseApi(api_client.Api):
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -348,6 +369,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _get_order_impact_oapg(
         self,
         body: typing.Any = None,
@@ -389,21 +411,31 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         if body is schemas.unset:
             raise exceptions.ApiValueError(
                 'The required body parameter has an invalid value of: unset. Set a valid value instead')
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         serialized_data = request_body_manual_trade_form.serialize(body, content_type)
-        _headers.add('Content-Type', content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
-            _body = serialized_data['body']    
+            _body = serialized_data['body']
+    
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -436,6 +468,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class GetOrderImpact(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
@@ -447,7 +480,7 @@ class GetOrderImpact(BaseApi):
         account_id: typing.Optional[str] = None,
         action: typing.Optional[Action] = None,
         order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -485,7 +518,7 @@ class GetOrderImpact(BaseApi):
         account_id: typing.Optional[str] = None,
         action: typing.Optional[Action] = None,
         order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -525,7 +558,7 @@ class ApiForpost(BaseApi):
         account_id: typing.Optional[str] = None,
         action: typing.Optional[Action] = None,
         order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -563,7 +596,7 @@ class ApiForpost(BaseApi):
         account_id: typing.Optional[str] = None,
         action: typing.Optional[Action] = None,
         order_type: typing.Optional[OrderType] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
